.. _install

Installing
==========

Installing with pip
-------------------

You can install ``pygeoid`` using the `pip package manager
<https://pypi.org/project/pip/>`__::

    pip install pygeoid


Installing the latest development version
-----------------------------------------

You can use ``pip`` to install the latest version of the source code from
GitHub::

    python -m pip install --upgrade git+https://github.com/ioshchepkov/pygeoid

